@@ -15,7 +15,7 @@
 #' For technical details, see Stevens and Olsen (2004).
 #'
 #'
-#' @param sframe The sampling frame as an \code{sf} object. The coordinate
+#' @param sframe A sampling frame as an \code{sf} object. The coordinate
 #'   system for \code{sframe} must projected (not geographic). If m or z values
 #'   are in \code{sframe}'s geometry, they are silently dropped (i.e., only x-coordinates
 #'   and y-coordinates are preserved).
@@ -76,7 +76,11 @@
 #' @param legacy_sites An sf object with a \code{POINT} or \code{MULTIPOINT}
 #'   geometry representing the legacy sites. spsurvey assumes that
 #'   the legacy sites were selected from a previous sampling design that
-#'   incorporated randomness into site selection. If m or z values
+#'   incorporated randomness into site selection and that the legacy sites
+#'   are elements of the current sampling frame. If \code{sframe} has a 
+#'   \code{POINT} or \code{MULTIPOINT} geometry, the observations in \code{legacy_sites}
+#'   should not also be in \code{sframe} (i.e., duplicates are not removed). Thus, \code{sframe}
+#'   and \code{legacy_sites} together compose the current sampling frame. If m or z values
 #'   are in \code{legacy_sites}' geometry, they are silently dropped (i.e., only x-coordinates
 #'   and y-coordinates are preserved).
 #'
@@ -111,9 +115,9 @@
 #'   \code{legacy_var} column must be \code{NA}. Using this approach,
 #'   \code{legacy_stratum_var}, \code{legacy_caty_var}, and \code{legacy_aux_var}
 #'   are not required and should not be used (because \code{legacy_var} represents a column
-#'   in \code{sframe}). spsurvey assumes that the legacy sites were selected from
-#'   a previous sampling design that
-#'   incorporated randomness into site selection.
+#'   in \code{sframe}). \code{spsurvey} assumes that the legacy sites were selected from
+#'   a previous sampling design that incorporated randomness into site selection
+#'   and that the legacy sites are elements of the current sampling frame.
 #'
 #' @param mindis A numeric value indicating the desired minimum distance between sampled
 #'   sites. If the sampling design is stratified and \code{mindis} is an numeric value, the minimum
@@ -225,16 +229,32 @@
 #'     \item \code{design} A list documenting the specifications of this sampling design.
 #'       This can be checked to verify your sampling design ran as intended.
 #'       \itemize{
-#'         \item \code{Call} The original function call.
+#'         \item \code{call} The original function call.
+#'         \item \code{stratum_var} The name of the stratification variable in \code{sframe}.
+#'           This equals \code{NULL} if no stratification is used.
 #'         \item \code{stratum} The unique strata. This equals \code{"None"} if
-#'           the sampling design was unstratified.
+#'           the sampling design is unstratified.
 #'         \item \code{n_base} The base sample size per stratum.
 #'         \item \code{seltype} The selection type per stratum.
+#'         \item \code{caty_var} The name of the unequal probability variable in \code{sframe}.
+#'           This equals \code{NULL} if no unequal probability variable is used.
 #'         \item \code{caty_n} The expected sample sizes for each level of the
 #'           unequal probability grouping variable per stratum. This equals
 #'           \code{NULL} when \code{seltype} is not \code{"unequal"}.
+#'         \item \code{aux_var} The name of the proportional probability (auxiliary) variable in \code{sframe}.
+#'           This equals \code{NULL} if no proportional probability variable is used.
 #'         \item \code{legacy} A logical variable indicating whether legacy sites
 #'           were included in the sample.
+#'         \item \code{legacy_stratum_var} The name of the stratification variable in \code{legacy_sites}.
+#'           Omitted if legacy sites are not used. This equals \code{NULL} if legacy sites were used but
+#'           no stratification variable is used.
+#'         \item \code{legacy_caty_var} The name of the unequal probability variable in \code{legacy_sites}.
+#'           Omitted if legacy sites are not used. This equals \code{NULL} if legacy sites were used but
+#'           no unequal probability variable is used.
+#'         \item \code{legacy_aux_var} The name of the proportional probability (auxiliary)
+#'           variable in \code{legacy_sites}.
+#'           Omitted if legacy sites are not used. This equals \code{NULL} if legacy sites
+#'           were used but no proportional probability variable is used.
 #'         \item \code{mindis} The minimum distance requirement desired. This
 #'           is \code{NULL} when no minimum distance requirement was applied.
 #'         \item \code{n_over} The reverse hierarchically ordered replacement
@@ -285,7 +305,8 @@
 #'   }
 #'   If any columns in \code{sframe} contain these names, those columns
 #'   from \code{sframe} will be automatically prefixed with \code{sframe_}
-#'   in the \code{sites} object.
+#'   in the \code{sites} object. When output is printed, a summary of site counts by
+#'   the levels in \code{stratum_var} and \code{caty_var} is shown.
 #'
 #' @author Tony Olsen \email{olsen.tony@@epa.gov}
 #'
@@ -300,10 +321,13 @@
 #'
 #' @examples
 #' \dontrun{
-#' sample <- grts(NE_Lakes, n_base = 100)
+#' samp <- grts(NE_Lakes, n_base = 100)
+#' print(samp)
 #' strata_n <- c(low = 25, high = 30)
-#' sample_strat <- grts(NE_Lakes, n_base = strata_n, stratum_var = "ELEV_CAT")
-#' sample_over <- grts(NE_Lakes, n_base = 30, n_over = 5)
+#' samp_strat <- grts(NE_Lakes, n_base = strata_n, stratum_var = "ELEV_CAT")
+#' print(samp_strat)
+#' samp_over <- grts(NE_Lakes, n_base = 30, n_over = 5)
+#' print(samp_over)
 #' }
 #' @export
 ################################################################################
@@ -329,7 +353,12 @@ grts <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var =
     names(legacy_sites)[names(legacy_sites) == legacy_geom_name] <- sframe_geom_name
     st_geometry(legacy_sites) <- sframe_geom_name
   }
-
+  
+  # save initial variable specifications for the design list later
+  initial_stratum_var <- stratum_var
+  initial_caty_var <- caty_var
+  initial_aux_var <- aux_var
+  
   # Create warning indicator and data frame to collect all potential issues during
   # sample selection
   warn_ind <- FALSE
@@ -463,6 +492,11 @@ grts <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var =
       legacy_sites$legacy <- legacy_sites[[legacy_var]]
     }
   }
+  
+  # save initial variable specifications for the design list later
+  initial_legacy_stratum_var <- legacy_stratum_var
+  initial_legacy_caty_var <- legacy_caty_var
+  initial_legacy_aux_var <- legacy_aux_var
 
   ## Create a dsgn list object
   # variable assignments to dsgn list object
@@ -870,11 +904,18 @@ grts <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var =
   # add function call to dsgn list
   # dsgn <- c(list(Call = match.call()), dsgn)
   dsgn <- list(
-    call = match.call(), stratum = dsgn$stratum, n_base = dsgn$n_base,
-    seltype = dsgn$seltype, caty_n = dsgn$caty_n, legacy = dsgn$legacy_option,
+    call = match.call(), stratum_var = initial_stratum_var, stratum = dsgn$stratum, n_base = dsgn$n_base,
+    seltype = dsgn$seltype, caty_var = initial_caty_var, caty_n = dsgn$caty_n, aux_var = initial_aux_var, legacy = dsgn$legacy_option,
     mindis = dsgn$mindis, n_over = dsgn$n_over, n_near = dsgn$n_near
   )
 
+  if (any(dsgn$legacy)) {
+    dsgn <- c(dsgn, list(legacy_stratum_var = initial_legacy_stratum_var, legacy_caty_var = initial_legacy_caty_var,
+                         legacy_aux_var = initial_legacy_aux_var))
+    dsgn <- dsgn[c("call", "stratum_var", "stratum", "n_base", "seltype", "caty_var",
+                   "caty_n", "aux_var", "legacy", "legacy_stratum_var", "legacy_caty_var", "legacy_aux_var",
+                   "mindis", "n_over", "n_near")]
+  }
 
   # create output list
   sites <- list(
@@ -896,7 +937,7 @@ grts <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var =
   }
 
   # constructor for design class
-  sites <- structure(sites, class = "spdesign")
+  sites <- structure(sites, class = "sp_design")
 
   # return the survey design sf object
   invisible(sites)
